==> v1.2017.17.tar.gz: plantuml/src/net/sourceforge/plantuml/project3/TaskCode.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.project3;

import java.util.Arrays;
import java.util.List;

import net.sourceforge.plantuml.cucadiagram.Display;

public class TaskCode {

	private final List<String> hierarchy;

	public TaskCode(String code) {
		this.hierarchy = Arrays.asList(code.split("/"));
	}

	public boolean startsWith(TaskCode other) {
		if (other.hierarchy.size() > this.hierarchy.size()) {
			return false;
		}
		assert other.hierarchy.size() <= this.hierarchy.size();
		final List<String> sub = this.hierarchy.subList(0, other.hierarchy.size());
		return sub.equals(other.hierarchy);
	}

	private TaskCode(List<String> hierarchy) {
		this.hierarchy = hierarchy;
	}

	public TaskCode truncateHierarchy(int size) {
		return new TaskCode(this.hierarchy.subList(0, size));
	}

	@Override
	public int hashCode() {
		return hierarchy.hashCode();
	}

	@Override
	public boolean equals(Object arg) {
		final TaskCode other = (TaskCode) arg;
		return this.hierarchy.equals(other.hierarchy);
	}

	@Override
	public String toString() {
		return hierarchy.toString();
	}

	public Display getSimpleDisplay() {
		final String last = hierarchy.get(hierarchy.size() - 1);
		return Display.getWithNewlines(last);
	}

	public int getHierarchySize() {
		return hierarchy.size();
	}

}

==> v1.2019.0.tar.gz: plantuml/src/net/sourceforge/plantuml/project3/TaskCode.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.project3;

import java.util.Arrays;
import java.util.List;

import net.sourceforge.plantuml.cucadiagram.Display;

public class TaskCode {

	private final List<String> hierarchy;

	public TaskCode(String code) {
		this.hierarchy = Arrays.asList(code.split("/"));
	}

	public boolean startsWith(TaskCode other) {
		if (other.hierarchy.size() > this.hierarchy.size()) {
			return false;
		}
		assert other.hierarchy.size() <= this.hierarchy.size();
		final List<String> sub = this.hierarchy.subList(0, other.hierarchy.size());
		return sub.equals(other.hierarchy);
	}

	private TaskCode(List<String> hierarchy) {
		this.hierarchy = hierarchy;
	}

	public TaskCode truncateHierarchy(int size) {
		return new TaskCode(this.hierarchy.subList(0, size));
	}

	@Override
	public int hashCode() {
		return hierarchy.hashCode();
	}

	@Override
	public boolean equals(Object arg) {
		final TaskCode other = (TaskCode) arg;
		return this.hierarchy.equals(other.hierarchy);
	}

	@Override
	public String toString() {
		return hierarchy.toString();
	}

	public String getSimpleDisplay() {
		return hierarchy.get(hierarchy.size() - 1);
	}

	public int getHierarchySize() {
		return hierarchy.size();
	}

}
